#ifndef ELEVATORSCONTROLSYSTEM_H
#define ELEVATORSCONTROLSYSTEM_H

#include <QObject>
#include <QVector>
#include "elevator.h"
#include "floor.h"
#include "passenger.h"
#include "alarmtype.h"

class ElevatorControlSystem : public QObject
{
    Q_OBJECT

public:
    ElevatorControlSystem(QVector<Elevator*> elevators, QVector<Floor*> floors, QVector<Passenger*> passengers, QObject *parent = nullptr);
    ~ElevatorControlSystem();

    const QVector<Elevator*>& getElevators() const;
    void handleAlarm(AlarmType alarmType);
    void reset();

private slots:
    void handleElevatorArrivedAtFloor(Elevator* elevator, int floor);
    void handleElevatorDoorStatusChanged(Elevator* elevator, bool open);
    void handleElevatorLoadChanged(Elevator* elevator, int load);
    void handleElevatorAlarmTriggered(Elevator* elevator, AlarmType alarmType);
    void handleFloorUpButtonPressed(Floor* floor, int floorNumber);
    void handleFloorDownButtonPressed(Floor* floor, int floorNumber);
    void handlePassengerDestinationFloorChanged(Passenger* passenger, int floor);
    void handlePassengerBoardingElevator(Passenger* passenger, int elevator);
    void handlePassengerExitingElevator(Passenger* passenger, int elevator);

private:
    QVector<Elevator*> elevators;
    QVector<Floor*> floors;
    QVector<Passenger*> passengers;

    bool shouldBoardElevator(Passenger* passenger, Elevator* elevator) const;
    void goToSafeFloor(int floor);
    void dispatchElevator(int floorNumber, ElevatorDirection direction);

    // Add any other necessary private members
};

#endif // ELEVATORSCONTROLSYSTEM_H
