#include "floor.h"
#include "eventlogger.h"

// Floor class basically just holds each Passengers up and down buttons
// These buttons are what dispatch the elevators
Floor::Floor(int floorNumber, QVector<QPushButton*> upButtons, QVector<QPushButton*> downButtons, QObject *parent)
    : QObject(parent), floorNumber(floorNumber), upButtons(upButtons), downButtons(downButtons)
{
    for (auto button : upButtons) {
        connect(button, &QPushButton::pressed, this, &Floor::handleUpButtonPressed);
    }

    for (auto button : downButtons) {
        connect(button, &QPushButton::pressed, this, &Floor::handleDownButtonPressed);
    }
}

Floor::~Floor()
{
}

int Floor::getFloorNumber() const
{
    return floorNumber;
}

bool Floor::isUpButtonPressed() const
{
    for (auto button : upButtons) {
        if (button->isDown())
            return true;
    }
    return false;
}

bool Floor::isDownButtonPressed() const
{
    for (auto button : downButtons) {
        if (button->isDown())
            return true;
    }
    return false;
}

void Floor::resetUpButtons() const
{
    for (auto it = upButtons.begin(); it != upButtons.end(); ++it) {
        QPushButton* up = *it;
        if (!up->isChecked() && !up->isEnabled()) continue;
        up->setChecked(false);
        up->setDisabled(false);
    }
}

void Floor::resetDownButtons() const
{
    for (auto it = downButtons.begin(); it != downButtons.end(); ++it) {
        QPushButton* down = *it;
        if (!down->isChecked() && !down->isEnabled()) continue;
        down->setChecked(false);
        down->setDisabled(false);
    }
}

const QVector<Passenger*>& Floor::getPeople() const
{
    return people;
}

void Floor::addPerson(Passenger* p)
{
    people.append(p);
    /*for (auto it = downButtons.begin(); it != downButtons.end(); ++it) {
        QPushButton* down = *it;
        if((!down->isChecked() && !down->isEnabled()) || (!down->isChecked() && down->isEnabled())) {
            handleFloorRequestButtonsDown();
        }
    }
    for (auto it = upButtons.begin(); it != upButtons.end(); ++it) {
        QPushButton* up = *it;
        if((!up->isChecked() && !up->isEnabled()) || (!up->isChecked() && up->isEnabled())) {
            handleFloorRequestButtonsUp();
        }
    }*/
}

void Floor::removePerson(Passenger* p)
{
    people.removeOne(p);
}

void Floor::handleUpButtonPressed()
{
    handleFloorRequestButtonsUp();
    EventLogger::getInstance().logEvent(QString("Floor %1 requested Elevator going UP").arg(getFloorNumber() + 1));
    emit upButtonPressed(floorNumber);
}

void Floor::handleDownButtonPressed()
{
    handleFloorRequestButtonsDown();
    EventLogger::getInstance().logEvent(QString("Floor %1 requested Elevator going DOWN").arg(getFloorNumber() + 1));
    emit downButtonPressed(floorNumber);
}

void Floor::handleFloorRequestButtonsDown() const
{
    for (auto it = downButtons.begin(); it != downButtons.end(); ++it) {
        QPushButton* down = *it;
        if (!down->isChecked() && !down->isEnabled()) continue;
        down->setChecked(true);
        down->setDisabled(true);
    }
}

void Floor::handleFloorRequestButtonsUp() const
{
    for (auto it = upButtons.begin(); it != upButtons.end(); ++it) {
        QPushButton* up = *it;
        if (!up->isChecked() && !up->isEnabled()) continue;
        up->setChecked(true);
        up->setDisabled(true);
    }
}
