#ifndef FLOOR_H
#define FLOOR_H

#include <QObject>
#include <QPushButton>
#include <QVector>
#include "passenger.h"

class Floor : public QObject
{
    Q_OBJECT

public:
    explicit Floor(int floorNumber, QVector<QPushButton*> upButtons, QVector<QPushButton*> downButtons, QObject *parent = nullptr);
    ~Floor();

    int getFloorNumber() const;
    bool isUpButtonPressed() const;
    bool isDownButtonPressed() const;
    void addPerson(Passenger* p);
    void removePerson(Passenger* p);
    const QVector<Passenger*>& getPeople() const;
    void resetUpButtons() const;
    void resetDownButtons() const;

signals:
    void upButtonPressed(int floorNumber);
    void downButtonPressed(int floorNumber);

private slots:
    void handleUpButtonPressed();
    void handleDownButtonPressed();

private:
    int floorNumber;
    QVector<QPushButton*> upButtons;
    QVector<QPushButton*> downButtons;
    QVector<Passenger*> people;

    void handleFloorRequestButtonsUp() const;
    void handleFloorRequestButtonsDown() const;
};

#endif // FLOOR_H
