#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QVector>
#include "elevator.h"
#include "floor.h"
#include "passenger.h"

extern const int NUM_ELEVATORS;
extern const int NUM_FLOORS;
extern const int NUM_PASSENGERS;

QT_BEGIN_NAMESPACE
namespace Ui { class MainWindow; }
QT_END_NAMESPACE

class ElevatorControlSystem;
class EventLogger;

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    MainWindow(QWidget *parent = nullptr);
    ~MainWindow();

private slots:
    void handlePassengerButton();
    void on_fireButton_clicked();
    void on_powerOutButton_clicked();
    void on_maxCapSlider_valueChanged(int value);

    void on_resetButton_clicked();

private:
    Ui::MainWindow *ui;
    ElevatorControlSystem* controlSystem;
    EventLogger& eventLogger;

    QVector<Elevator*> setupElevators();
    QVector<Floor*> setupFloors();
    QVector<Passenger*> setupPassengers();
    QVector<QLayout*> getPassengerTabLayouts();

    QList<QPushButton*> getFloorSelectors(int passengerNumber);

    void setupElevatorControlSystem();
    void setupConnections();
};

#endif // MAINWINDOW_H
