#ifndef PASSENGER_H
#define PASSENGER_H

#include <QObject>
#include <QWidget>
#include <QVector>
#include <QPushButton>
#include <QLabel>

class Passenger : public QObject
{
    Q_OBJECT

public:
    Passenger(int id, QLabel* passengerStateDisplay, QVector<QPushButton*> desiredFloorButtons, QVector<QPushButton*> directionFloorButtons, QVector<QPushButton*> passengerIndicators, QObject* parent = nullptr);
    ~Passenger();

    int getId() const;
    int getCurrentFloor() const;
    int getDestinationFloor() const;
    int getBoardedElevator() const;
    void lock() const;

    void updateButtonsAndIndicators(int newFloor);

public slots:
    void setCurrentFloor(int floor);
    void setDestinationFloor(int floor);
    void boardElevator(int elevator);
    void exitElevator(int elevator);

private slots:
    void handleDesiredFloorButtonClick(QPushButton* button, const QVector<QPushButton*>& desiredFloorButtons, int currentFloor);

signals:
    void floorChanged(int floor);
    void destinationFloorChanged(int floor);
    void boardingElevator(int elevator);
    void exitingElevator(int elevator);

private:
    int id;
    int currentFloor;
    int destinationFloor;
    int boardedElevator;
    // Why we have UI elements here is these elements are what the passenger sees
    // Therefore they are directly related to the passenger (i.e controlling the passenger)
    // Thus it makes sense control these elements from the passenger class
    QLabel* passengerStateDisplay;
    QVector<QPushButton*> desiredFloorButtons;
    QVector<QPushButton*> directionFloorButtons;
    QVector<QPushButton*> passengerIndicators;


    int extractFloorFromButtonName(const QString& buttonName);

};

#endif // PASSENGER_H
